[Scummvm-git-logs] scummvm master -> d03475e5abbbce905d1f4914198dddcd01250ac1

bgK bastien.bouclet at gmail.com
Wed Jul 19 07:23:59 CEST 2017


This automated email contains information about 2 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
a7dd81060b MOHAWK: Riven: Fix the ending movie looping in the Rebel age
d03475e5ab MOHAWK: Riven: Speed up the credits


Commit: a7dd81060bc6f1d010d61d6fcf273e618acbb52e
    https://github.com/scummvm/scummvm/commit/a7dd81060bc6f1d010d61d6fcf273e618acbb52e
Author: Bastien Bouclet (bastien.bouclet at gmail.com)
Date: 2017-07-19T07:23:32+02:00

Commit Message:
MOHAWK: Riven: Fix the ending movie looping in the Rebel age

Fixes #9969.

Changed paths:
    engines/mohawk/riven_stack.cpp


diff --git a/engines/mohawk/riven_stack.cpp b/engines/mohawk/riven_stack.cpp
index d3c76ed..2931383 100644
--- a/engines/mohawk/riven_stack.cpp
+++ b/engines/mohawk/riven_stack.cpp
@@ -188,6 +188,7 @@ void RivenStack::runEndGame(uint16 videoCode, uint32 delay) {
 	RivenVideo *video = _vm->_video->openSlot(videoCode);
 	video->enable();
 	video->play();
+	video->setLooping(false);
 	runCredits(videoCode, delay);
 }
 


Commit: d03475e5abbbce905d1f4914198dddcd01250ac1
    https://github.com/scummvm/scummvm/commit/d03475e5abbbce905d1f4914198dddcd01250ac1
Author: Bastien Bouclet (bastien.bouclet at gmail.com)
Date: 2017-07-19T07:23:32+02:00

Commit Message:
MOHAWK: Riven: Speed up the credits

Fixes #9970.

Changed paths:
    engines/mohawk/riven_stack.cpp


diff --git a/engines/mohawk/riven_stack.cpp b/engines/mohawk/riven_stack.cpp
index 2931383..0a274b2 100644
--- a/engines/mohawk/riven_stack.cpp
+++ b/engines/mohawk/riven_stack.cpp
@@ -207,11 +207,11 @@ void RivenStack::runCredits(uint16 video, uint32 delay) {
 				nextCreditsFrameStart = _vm->getTotalPlayTime() + delay;
 			} else if (_vm->getTotalPlayTime() >= nextCreditsFrameStart) {
 				// the first two frames stay on for 4 seconds
 				// the rest of the scroll updates happen at 30Hz
 				if (_vm->_gfx->getCurCreditsImage() < 304)
 					nextCreditsFrameStart = _vm->getTotalPlayTime() + 4000;
 				else
-					nextCreditsFrameStart = _vm->getTotalPlayTime() + 1000 / 30;
+					nextCreditsFrameStart = _vm->getTotalPlayTime() + 1000 / 60;
 
 				_vm->_gfx->updateCredits();
 			}
@@ -207,11 +207,11 @@ void RivenStack::runCredits(uint16 video, uint32 delay) {
 			} else if (_vm->getTotalPlayTime() >= nextCreditsFrameStart) {
 				// the first two frames stay on for 4 seconds
-				// the rest of the scroll updates happen at 30Hz
+				// the rest of the scroll updates happen at 60Hz
 				if (_vm->_gfx->getCurCreditsImage() < 304)
 					nextCreditsFrameStart = _vm->getTotalPlayTime() + 4000;





More information about the Scummvm-git-logs mailing list